@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -10,8 +10,7 @@
 # Default configuration for OTRS. All changes to this file will be lost after an
 #   update, please use AdminSystemConfiguration to configure your system.
 
-## nofilter(TidyAll::Plugin::Znuny::Perl::LayoutObject)
-## nofilter(TidyAll::Plugin::Znuny::CodeStyle::STDERRCheck)
+## nofilter(TidyAll::Plugin::OTRS::Perl::LayoutObject)
 
 package Kernel::Config::Defaults;
 
@@ -914,15 +913,15 @@ sub LoadDefaults {
     # --------------------------------------------------- #
     # MIME-Viewer for online to html converter
     # --------------------------------------------------- #
-    # (e.g. xlhtml (xls2html), http://chicago.sourceforge.net/xlhtml/)
-#     $Self->{'MIME-Viewer'}->{'application/excel'} = 'xlhtml';
+    # (e. g. xlhtml (xls2html), http://chicago.sourceforge.net/xlhtml/)
+#    $Self->{'MIME-Viewer'}->{'application/excel'} = 'xlhtml';
     # MIME-Viewer for online to html converter
-    # (e.g. wv (word2html), http://wvware.sourceforge.net/)
-#     $Self->{'MIME-Viewer'}->{'application/msword'} = 'wvWare';
-    # (e.g. pdftohtml (pdf2html), http://pdftohtml.sourceforge.net/)
-#     $Self->{'MIME-Viewer'}->{'application/pdf'} = 'pdftohtml -stdout -i';
-    # (e.g. xml2html (xml2html))
-#     $Self->{'MIME-Viewer'}->{'text/xml'} = $Self->{Home}.'/scripts/tools/xml2html.pl';
+    # (e. g. wv (word2html), http://wvware.sourceforge.net/)
+#    $Self->{'MIME-Viewer'}->{'application/msword'} = 'wvWare';
+    # (e. g. pdftohtml (pdf2html), http://pdftohtml.sourceforge.net/)
+#    $Self->{'MIME-Viewer'}->{'application/pdf'} = 'pdftohtml -stdout -i';
+    # (e. g. xml2html (xml2html))
+#    $Self->{'MIME-Viewer'}->{'text/xml'} = $Self->{Home}.'/scripts/tools/xml2html.pl';
 
     # --------------------------------------------------- #
     # directories                                         #
@@ -993,10 +992,10 @@ sub LoadDefaults {
         'thirdparty/jquery-3.5.1/jquery.js',
         'thirdparty/jquery-browser-detection/jquery-browser-detection.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
-        'thirdparty/jquery-ui-1.13.1/jquery-ui.js',
+        'thirdparty/jquery-ui-1.12.1/jquery-ui.js',
         'thirdparty/jquery-pubsub/pubsub.js',
         'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
-        'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
+        'thirdparty/nunjucks-3.0.1/nunjucks.js',
         'Core.Init.js',
         'Core.Debug.js',
         'Core.Exception.js',
@@ -1030,12 +1029,12 @@ sub LoadDefaults {
     $Self->{'Loader::Agent::CommonJS'}->{'000-Framework'} = [
         'thirdparty/jquery-3.5.1/jquery.js',
         'thirdparty/jquery-browser-detection/jquery-browser-detection.js',
-        'thirdparty/jquery-ui-1.13.1/jquery-ui.js',
+        'thirdparty/jquery-ui-1.12.1/jquery-ui.js',
         'thirdparty/jquery-ui-touch-punch-0.2.3/jquery.ui.touch-punch.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
         'thirdparty/jquery-pubsub/pubsub.js',
         'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
-        'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
+        'thirdparty/nunjucks-3.0.1/nunjucks.js',
         'Core.Init.js',
         'Core.JavaScriptEnhancements.js',
         'Core.Debug.js',
@@ -2066,9 +2065,9 @@ sub Get {
 sub Set {
     my ( $Self, %Param ) = @_;
 
-    for my $Key (qw(Key)) {
-        if ( !defined $Param{$Key} ) {
-            $Param{$Key} = '';
+    for (qw(Key)) {
+        if ( !defined $Param{$_} ) {
+            $Param{$_} = '';
         }
     }
 
@@ -2101,7 +2100,7 @@ sub Set {
     return 1;
 }
 
-## nofilter(TidyAll::Plugin::Znuny::Perl::Translatable)
+## nofilter(TidyAll::Plugin::OTRS::Perl::Translatable)
 
 # This is a no-op to mark a text as translatable in the Perl code.
 #   We use our own version here instead of importing Language::Translatable to not add a dependency.
@@ -2170,7 +2169,7 @@ sub AutoloadPerlPackages {
             # Don't use the MainObject here to load the file.
             eval {
                 my $FileName = $Package =~ s{::}{/}smxgr;
-                require $FileName . '.pm'; ## nofilter(TidyAll::Plugin::Znuny::Perl::Require)
+                require $FileName . '.pm'; ## nofilter(TidyAll::Plugin::OTRS::Perl::Require)
             };
         }
     }
